@@ -4,9 +4,11 @@ pub trait Encoded {
     fn __get(&self) -> &[u8];
 }
 
+#[cfg(feature = "deprecated-byte-patterns")]
 #[derive(Clone)]
 pub struct EncodedByte([u8; 1]);
 
+#[cfg(feature = "deprecated-byte-patterns")]
 impl Encoded for EncodedByte {
     #[inline]
     fn __get(&self) -> &[u8] {
@@ -86,6 +88,11 @@ impl<'a> Pattern for &'a String {
     }
 }
 
+#[cfg(feature = "deprecated-byte-patterns")]
+#[cfg_attr(
+    os_str_bytes_docs_rs,
+    doc(cfg(feature = "deprecated-byte-patterns"))
+)]
 impl Pattern for u8 {
     #[doc(hidden)]
     type __Encoded = EncodedByte;
